#ifndef TEXTFORMATUTILS_H
#define TEXTFORMATUTILS_H

#include <QWidget>
#include <QPlainTextEdit>
#include <QFontDialog>
#include <QColorDialog>
#include <QInputDialog>


class TextFormatUtils
{
public:
    static void changeFontSize(QWidget* parent);
    static void changeFontColor(QWidget* parent);
    static void changeFont(QWidget* parent);
    static void toggleBold();
    static void toggleItalic();
    static void toggleUnderline();
    static void toggleOverline();

private:
    static QPlainTextEdit* getFocusedPlainTextEdit();
};

#endif // TEXTFORMATUTILS_H
